#虚谷JDBC负载均衡使用说明

	JDBC内置均衡接口:基于调用者传入的多个连接ip地址和其他连接信息，通过内部均衡算法实现了用户请求建立的数据库连接均衡的分布在虚谷数据库集群的各个节点上。

    JDBC负载均衡接口分为配置文件和非配置文件两种方式
    
    + 标准jdbc
    
    url连接串：jdbc:xugu://127.0.0.1:5138/SYSTEM?user=SYSDBA&password=SYSDBA&char_set=utf8
    
    + 配置文件方式
    
    url连接串：jdbc:xugu:file://listener.xml:5138/SYSTEM?user=SYSDBA&password=SYSDBA&char_set=utf8
    
    + 非配置文件方式
    
    url连接串：jdbc:xugu://127.0.0.1:5138/SYSTEM?user=SYSDBA&password=SYSDBA&char_set=utf8&ips=192.168.1.2,192.168.1.2,192.168.1.2

##一、配置文件方式

		1. 协议头由标准方式"jdbc:xugu:"变为"jdbc:xugu:file:"
		
		2. ip替换为配置文件*.xml,配置文件格式如下：
        
            <?xml version="1.0" encoding="utf-8"?>
            <listeners>
                <listener>
                    <ip>192.168.1.206</ip>
                </listener>
                <listener>
                    <ip>192.168.1.204</ip>
                </listener>
                <listener>
                    <ip>192.168.1.205</ip>
                </listener>
            </listeners>
            
		3. 使用方式demo代码：
		
		public Connection getConnectionByFile() throws ClassNotFoundException, SQLException
            {
                Class.forName("com.xugu.cloudjdbc.Driver");
                conn = DriverManager.getConnection("jdbc:xugu:file://xuguClouldListener.xml:5138/SYSTEM?user=SYSDBA&password=SYSDBA");
                return conn;
            }
    
##二、非配置文件方式

###使用方式demo代码(连接部分)：

    /**
	 * 非配置文件，负责均衡使用方式一
	 * 均衡节点逗号分隔赋予ips 置于连接串后
	 * @return
	 * @throws ClassNotFoundException
	 * @throws SQLException
	 */
	public Connection getConnectionByProps1() throws ClassNotFoundException, SQLException
	{
		Class.forName("com.xugu.cloudjdbc.Driver");
		conn = DriverManager.getConnection("jdbc:xugu://192.168.1.201:5138/SYSTEM?user=SYSDBA&password=SYSDBA" +
				"&ips=192.168.1.205,192.168.1.204,192.168.1.206");
		return conn;
	}

	/**
	 * 非配置文件，负责均衡使用方式二
	 * 均衡节点放入Vector<String>对象后put到ips
	 * @return
	 * @throws ClassNotFoundException
	 * @throws SQLException
	 */
	public Connection getConnectionByProps2() throws ClassNotFoundException, SQLException
	{
		Class.forName("com.xugu.cloudjdbc.Driver");
		Properties info=new Properties();
		
		Vector<String> ipsVector=new Vector<String>();
		ipsVector.add("192.168.1.201");
		ipsVector.add("192.168.1.204");
		ipsVector.add("192.168.1.205");
		ipsVector.add("192.168.1.206");
		info.put("ips", ipsVector);
		conn = DriverManager.getConnection("jdbc:xugu://192.168.1.201:5138/SYSTEM?user=SYSDBA&password=SYSDBA",info);
		return conn;
	}
    
	/**
	 * 非配置文件，负责均衡使用方式三
	 * 均衡节点放入String数组对象后put到ips
	 * @return
	 * @throws ClassNotFoundException
	 * @throws SQLException
	 */
	public Connection getConnectionByProps3() throws ClassNotFoundException, SQLException
	{
		Class.forName("com.xugu.cloudjdbc.Driver");
		Properties info=new Properties();
		String[] ips={"192.168.1.205","192.168.1.204","192.168.1.206"};
		info.put("ips", ips);
		conn = DriverManager.getConnection("jdbc:xugu://192.168.1.201:5138/SYSTEM?user=SYSDBA&password=SYSDBA",info);
		return conn;
	}
    
	/**
	 * 非配置文件，负责均衡使用方式四
	 * 均衡节点形成逗号分隔字符串对象后put到ips
	 * @return
	 * @throws ClassNotFoundException
	 * @throws SQLException
	 */
	public Connection getConnectionByProps4() throws ClassNotFoundException, SQLException
	{
		Class.forName("com.xugu.cloudjdbc.Driver");
		Properties info=new Properties();
		String ips="192.168.1.205,192.168.1.204,192.168.1.206";
		info.put("ips", ips);
		conn = DriverManager.getConnection("jdbc:xugu://192.168.1.201:5138/SYSTEM?user=SYSDBA&password=SYSDBA",info);
		return conn;
	}
